#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-core
version:              1.6.28.0
visibility:           public
id:                   yesod-core-1.6.28.0-7AIRiWg47ydIx3s9b7d5bi
key:                  yesod-core-1.6.28.0-7AIRiWg47ydIx3s9b7d5bi
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  cb8f88191bc8d8e3d7ece7eb59ce5c14
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-core-1.6.28.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-core
hs-libraries:         HSyesod-core-1.6.28.0-7AIRiWg47ydIx3s9b7d5bi
depends:
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx
    attoparsec-aeson-2.2.0.1-7qhA8MoAIr93DDFtpEOy9M
    auto-update-0.1.6-4w7IsaH04QYB7ELNh8e7pg base-4.18.2.1
    blaze-html-0.9.2.0-GrDzB1jIZhp1oZYOXFcy0G
    blaze-markup-0.8.3.0-cyi0Fpqe62J2suaFuJVt7 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-BUUMd5L4HIgpuJP9IYz4Q
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    clientsession-0.9.3.0-XfmbfyYaGM959u1YZPYb5
    conduit-1.3.6.1-ZW0r2gxsao1PdW3Ct9TSq
    conduit-extra-1.3.8-7ewFWVPnCG8Lw0URYbSD7 containers-0.6.7
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5
    data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8 deepseq-1.4.8.1
    entropy-0.4.1.11-1vtyWzOCursffXS6ZqzcH
    fast-logger-3.2.4-CE2vu3Xe4ZtFiMzyqfICFC
    http-types-0.12.4-CXiZJUbLhJFHeSLHvVo6Rt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-logger-0.3.42-Bq5w98EzoXU1aFwDtg835h mtl-2.3.1
    parsec-3.1.16.1 path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    primitive-0.9.1.0-5ZrX7WiTmxB6LlIfRXEiID
    random-1.2.1.3-DsZJWYr04hc2YE8pqhZcvw
    resourcet-1.2.6-Eyr7bfOz5d6K4XSFfoBWea
    shakespeare-2.1.7.1-Ah8qjAftenL32aOVzwD8Cd
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-3g4IDjp0vr0De46QhKcu9n
    unliftio-0.2.25.1-8PFdViM4kSw68msSMSHlHp
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd
    vector-0.13.2.0-DH6UT7zpR061zYDIVIbmaS
    wai-3.2.4-33aeOeERzkeGIF7OkDVW43
    wai-extra-3.1.18-GPfAccYZllpKjU4vNNDG0n
    wai-logger-2.5.0-8dpE5YImnmM5ZFEP9bRAMM
    warp-3.4.0-3cQ7FyihRHt3HbPBKLrLdw
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

